Overview
========

Currently ``ftw.journal`` provides two adapters to store infos.

- workflow_histoy
- annotations

Howto use:

- Simply Add a rule throught the plone ui.


Install
=======

- Add ``ftw.journal`` to your buildout configuration

::

  [instance]
  eggs =
    ftw.journal

- Run buildout

- Add rule through plone ui


Compatibility
-------------

Runs with `Plone <http://www.plone.org/>`_ `4.3` or `5.1`.


Links
=====

- Github: https://github.com/4teamwork/ftw.journal
- Issues: https://github.com/4teamwork/ftw.journal/issues
- Package will be on pypi: http://pypi.python.org/pypi/ftw.journal
- Continuous integration: https://jenkins.4teamwork.ch/search?q=ftw.journal


Copyright
---------

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``ftw.journal`` is licensed under GNU General Public License, version 2.
